pub struct BitVec<T, U: Integer>{ /* private fields */ }Implementations
Sourceimpl<T, U: Integer> BitVec<T, U>
impl<T, U: Integer> BitVec<T, U>
Sourcepub fn comp_pos(&self, i: usize) -> (usize, usize, usize, usize)
pub fn comp_pos(&self, i: usize) -> (usize, usize, usize, usize)
Returns the positions of the affected elements in the underlying values vec and the local start and end bit.
Sourcepub fn with_max_value(n: usize, val_max: T) -> Self
pub fn with_max_value(n: usize, val_max: T) -> Self
Returns a bit vec container with a maximum value. Internal variables are set, such that the underlying data vec does not have to be reallocated.
Sourcepub fn stride_bits(&self) -> u64
pub fn stride_bits(&self) -> u64
Returns the number of bits for each integer in the underlying vec.
Sourcepub fn mask(&self, start_bit: usize, end_bit: usize) -> U
pub fn mask(&self, start_bit: usize, end_bit: usize) -> U
Returns the mask filled with ones from start_bit to end_bit.
Sourcepub fn mask_inverse(&self, start_bit: usize, end_bit: usize) -> U
pub fn mask_inverse(&self, start_bit: usize, end_bit: usize) -> U
Returns the mask filled with zeroes from start_bit to end_bit, all the other bits are ones.